summaryrefslogtreecommitdiff
path: root/etc/themes/modus-operandi-tinted-theme.el
diff options
context:
space:
mode:
Diffstat (limited to 'etc/themes/modus-operandi-tinted-theme.el')
-rw-r--r--etc/themes/modus-operandi-tinted-theme.el84
1 files changed, 57 insertions, 27 deletions
diff --git a/etc/themes/modus-operandi-tinted-theme.el b/etc/themes/modus-operandi-tinted-theme.el
index 7e0ad3d7ea8..f112456034b 100644
--- a/etc/themes/modus-operandi-tinted-theme.el
+++ b/etc/themes/modus-operandi-tinted-theme.el
@@ -1,11 +1,11 @@
;;; modus-operandi-tinted-theme.el --- Elegant, highly legible theme with a light ocher background -*- lexical-binding:t -*-
;; Copyright (C) 2019-2024 Free Software Foundation, Inc.
;; Author: Protesilaos Stavrou <info@protesilaos.com>
-;; Maintainer: Modus-Themes Development <~protesilaos/modus-themes@lists.sr.ht>
-;; URL: https://git.sr.ht/~protesilaos/modus-themes
-;; Mailing-List: https://lists.sr.ht/~protesilaos/modus-themes
+;; Maintainer: Protesilaos Stavrou <info@protesilaos.com>
+;; URL: https://github.com/protesilaos/modus-themes
+;; Keywords: faces, theme, accessibility
;; This file is part of GNU Emacs.
@@ -44,7 +44,7 @@
;;;###theme-autoload
(deftheme modus-operandi-tinted
- "Elegant, highly legible theme with a light ocher background.
+ "Elegant, highly legible theme with a light ochre background.
Conforms with the highest legibility standard for color contrast
between background and foreground in any given piece of text,
which corresponds to a minimum contrast in relative luminance of
@@ -125,12 +125,12 @@ which corresponds to a minimum contrast in relative luminance of
(bg-magenta-subtle "#ffddff")
(bg-cyan-subtle "#bfefff")
- (bg-red-nuanced "#ffe8f0")
- (bg-green-nuanced "#e0f5e0")
- (bg-yellow-nuanced "#f9ead0")
- (bg-blue-nuanced "#ebebff")
- (bg-magenta-nuanced "#f6e7ff")
- (bg-cyan-nuanced "#e1f3fc")
+ (bg-red-nuanced "#ffe8e8")
+ (bg-green-nuanced "#e0f6e0")
+ (bg-yellow-nuanced "#f8f0d0")
+ (bg-blue-nuanced "#ecedff")
+ (bg-magenta-nuanced "#f8e6f5")
+ (bg-cyan-nuanced "#e0f2fa")
;;; Uncommon accent backgrounds
@@ -209,6 +209,7 @@ which corresponds to a minimum contrast in relative luminance of
;;; Paren match
(bg-paren-match "#7fdfcf")
+ (fg-paren-match fg-main)
(bg-paren-expression "#efd3f5")
(underline-paren-match unspecified)
@@ -217,9 +218,9 @@ which corresponds to a minimum contrast in relative luminance of
;;;; General mappings
(fringe bg-dim)
- (cursor red)
+ (cursor red-intense)
- (keybind blue-cooler)
+ (keybind red)
(name magenta)
(identifier yellow-cooler)
@@ -238,6 +239,11 @@ which corresponds to a minimum contrast in relative luminance of
(bg-prominent-note bg-cyan-intense)
(fg-prominent-note fg-main)
+ (bg-active-argument bg-yellow-nuanced)
+ (fg-active-argument yellow-warmer)
+ (bg-active-value bg-cyan-nuanced)
+ (fg-active-value cyan-warmer)
+
;;;; Code mappings
(builtin magenta-warmer)
@@ -340,16 +346,29 @@ which corresponds to a minimum contrast in relative luminance of
;;;; Prose mappings
- (prose-block fg-dim)
- (prose-code green-cooler)
+ (bg-prose-block-delimiter bg-dim)
+ (fg-prose-block-delimiter fg-dim)
+ (bg-prose-block-contents bg-dim)
+
+ (bg-prose-code unspecified)
+ (fg-prose-code cyan-cooler)
+
+ (bg-prose-macro unspecified)
+ (fg-prose-macro magenta-cooler)
+
+ (bg-prose-verbatim unspecified)
+ (fg-prose-verbatim magenta-warmer)
+
(prose-done green)
- (prose-macro magenta-cooler)
+ (prose-todo red)
+
(prose-metadata fg-dim)
(prose-metadata-value fg-alt)
+
(prose-table fg-alt)
+ (prose-table-formula magenta-warmer)
+
(prose-tag magenta-faint)
- (prose-todo red)
- (prose-verbatim magenta-warmer)
;;;; Rainbow mappings
@@ -363,6 +382,17 @@ which corresponds to a minimum contrast in relative luminance of
(rainbow-7 blue-warmer)
(rainbow-8 magenta-warmer)
+;;;; Search mappings
+
+ (bg-search-current bg-yellow-intense)
+ (bg-search-lazy bg-cyan-intense)
+ (bg-search-replace bg-red-intense)
+
+ (bg-search-rx-group-0 bg-blue-intense)
+ (bg-search-rx-group-1 bg-green-intense)
+ (bg-search-rx-group-2 bg-red-subtle)
+ (bg-search-rx-group-3 bg-magenta-subtle)
+
;;;; Space mappings
(bg-space unspecified)
@@ -371,10 +401,10 @@ which corresponds to a minimum contrast in relative luminance of
;;;; Terminal mappings
- (bg-term-black "black")
- (fg-term-black "black")
- (bg-term-black-bright "gray35")
- (fg-term-black-bright "gray35")
+ (bg-term-black "#000000")
+ (fg-term-black "#000000")
+ (bg-term-black-bright "#595959")
+ (fg-term-black-bright "#595959")
(bg-term-red red)
(fg-term-red red)
@@ -406,10 +436,10 @@ which corresponds to a minimum contrast in relative luminance of
(bg-term-cyan-bright cyan-cooler)
(fg-term-cyan-bright cyan-cooler)
- (bg-term-white "gray65")
- (fg-term-white "gray65")
- (bg-term-white-bright "white")
- (fg-term-white-bright "white")
+ (bg-term-white "#a6a6a6")
+ (fg-term-white "#a6a6a6")
+ (bg-term-white-bright "#ffffff")
+ (fg-term-white-bright "#ffffff")
;;;; Heading mappings
@@ -1,11 +1,11 @@
-;;; modus-operandi-tinted-theme.el --- Elegant, highly legible theme with a light ocher background -*- lexical-binding:t -*-
+;;; modus-operandi-tinted-theme.el --- Elegant, highly legible theme with a light ochre background -*- lexical-binding:t -*-
-;; Copyright (C) 2019-2024 Free Software Foundation, Inc.
+;; Copyright (C) 2019-2024 Free Software Foundation, Inc.
;; Author: Protesilaos Stavrou <info@protesilaos.com>